@@ -7,7 +7,7 @@ use warnings;
 use Wx;
 use utf8;
 our $NAME = __PACKAGE__;
-our $VERSION = '0.7';
+our $VERSION = '0.71';
 
 use base qw/Wx::App/;
 use App::GUI::Cellgraph::Frame;
@@ -84,7 +84,7 @@ and a deeper B<understanding> about how cellular automatons work.
 
 =for HTML <p>
 <img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/30.png"      alt=""  width="300" height="300">
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/sqrt.png"    alt=""  width="300" height="300">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/cascadestar.png"    alt=""  width="300" height="300">
 <img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/7io.png"     alt=""  width="300" height="300">
 <img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/teppich2.png"alt=""  width="300" height="300">
 <img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/igt.png"    alt=""  width="300" height="300">
@@ -92,18 +92,6 @@ and a deeper B<understanding> about how cellular automatons work.
 </p>
 
 
-=head1 GUI
-
-The general layout is very simple: the picture gets drawn on the left
-window side. On the right side you change the settings from which the
-picture is computed. Please note there the tabs, in the top row.
-They select which page of settings is visible.
-
-Please mind the tool tips - short help texts which appear if the mouse
-stands still over a button. Also helpful are messages in the status bar
-at the bottom that appear while browsing the menu of after a command given.
-
-
 =head1 Mechanics
 
 Every tile (square) in the picture represents one automaton (called B<cell>).
@@ -136,6 +124,17 @@ More details about this mechanics are to be found in the chapter
 "I<General Settings>" and "I<Action Rules>".
 
 
+=head2 GUI
+
+The general layout is very simple: the picture gets drawn on the left
+window side. On the right side you change the settings from which the
+picture is computed. Please note there the tabs, in the top row.
+They select which page of settings is visible.
+
+Please mind the tool tips - short help texts which appear if the mouse
+stands still over a button. Also helpful are messages in the status bar
+at the bottom that appear while browsing the menu of after a command given.
+
 =head2 General Settings
 
 =for HTML <p>
@@ -329,7 +328,7 @@ random amount.
 =head2 Colors
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIcolors.png" alt="" width="85%" height="85%">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIcolor7.png" alt="" width="85%" height="85%">
 </p>
 
 This panel helps you to customize the automaton/cell state colors, with
