@@ -1,3 +1,6 @@
+
+# color panel tab
+
 use v5.12;
 use warnings;
 use Wx;
@@ -10,7 +13,6 @@ use App::GUI::Cellgraph::Frame::Part::ColorPicker;
 use App::GUI::Cellgraph::Frame::Part::ColorSetPicker;
 use App::GUI::Cellgraph::Widget::ColorDisplay;
 use App::GUI::Cellgraph::Widget::PositionMarker;
-
 use Graphics::Toolkit::Color qw/color/;
 
 our $default_color_def = $App::GUI::Cellgraph::Frame::Part::ColorSetPicker::default_color;
@@ -29,28 +31,28 @@ sub new {
     $self->{'state_colors'}       = [ color('white')->gradient( to => 'black', steps => $self->{'state_count'}) ];
     $self->{'state_colors'}[$_]   = color( $default_color_def ) for $self->{'state_count'} .. $self->{'last_state'};
     $self->{'state_marker'}       = [ map { App::GUI::Cellgraph::Widget::PositionMarker->new($self, $self->{'rule_square_size'}, 20, $_, '', $default_color_def) } 0 ..$self->{'last_state'} ];
-    $self->{'state_pic'}[$_]      = App::GUI::Cellgraph::Widget::ColorDisplay->new($self, $self->{'rule_square_size'}, $self->{'rule_square_size'}, $_, $self->{'state_colors'}[$_]->values(as => 'hash'))
-        for 0 .. $self->{'last_state'};
-    $self->{'color_set_store_lbl'} = Wx::StaticText->new($self, -1, 'Color Set Store' );
-    $self->{'color_set_f_lbl'}   = Wx::StaticText->new($self, -1, 'Colors Set Function' );
-    $self->{'state_color_lbl'}   = Wx::StaticText->new($self, -1, 'Currently Used State Colors' );
-    $self->{'curr_color_lbl'}    = Wx::StaticText->new($self, -1, 'Selected State Color' );
-    $self->{'color_store_lbl'}   = Wx::StaticText->new($self, -1, 'Color Store' );
+    $self->{'state_pic'}[$_]      = App::GUI::Cellgraph::Widget::ColorDisplay->new
+        ($self, $self->{'rule_square_size'}, $self->{'rule_square_size'},
+         $_, $self->{'state_colors'}[$_]->values(as => 'hash')          ) for 0 .. $self->{'last_state'};
+    $self->{'color_set_store_lbl'}= Wx::StaticText->new($self, -1, 'Color Set Store' );
+    $self->{'color_set_f_lbl'}    = Wx::StaticText->new($self, -1, 'Colors Set Function' );
+    $self->{'state_color_lbl'}    = Wx::StaticText->new($self, -1, 'Currently Used State Colors' );
+    $self->{'curr_color_lbl'}     = Wx::StaticText->new($self, -1, 'Selected State Color' );
+    $self->{'color_store_lbl'}    = Wx::StaticText->new($self, -1, 'Color Store' );
 
-    $self->{'dynamics'} = Wx::ComboBox->new( $self, -1, 1, [-1,-1],[75, -1], [ 0.33, 0.5, 0.66, 0.83, 1, 1.2, 1.5, 2, 3 ]);
-    $self->{'Sdelta'} = Wx::TextCtrl->new( $self, -1, 0, [-1,-1], [50,-1], &Wx::wxTE_RIGHT);
-    $self->{'Ldelta'} = Wx::TextCtrl->new( $self, -1, 0, [-1,-1], [50,-1], &Wx::wxTE_RIGHT);
+    $self->{'widget'}{'dynamic'} = Wx::ComboBox->new( $self, -1, 1, [-1,-1],[75, -1], [ 0.2, 0.25, 0.33, 0.4, 0.5, 0.66, 0.7, 0.83, 0.9, 1, 1.2, 1.5, 2, 2.5, 3, 4 ]);
+    $self->{'widget'}{'delta_S'} = Wx::TextCtrl->new( $self, -1, 0, [-1,-1], [50,-1], &Wx::wxTE_RIGHT);
+    $self->{'widget'}{'delta_L'} = Wx::TextCtrl->new( $self, -1, 0, [-1,-1], [50,-1], &Wx::wxTE_RIGHT);
 
-
-    $self->{'btn'}{'gray'}       = Wx::Button->new( $self, -1, 'Gray',       [-1,-1], [45, 35] );
-    $self->{'btn'}{'gradient'}   = Wx::Button->new( $self, -1, 'Gradient',   [-1,-1], [70, 35] );
-    $self->{'btn'}{'complement'} = Wx::Button->new( $self, -1, 'Complement', [-1,-1], [90, 35] );
-    $self->{'btn'}{'gray'}->SetToolTip("reset to default grey scale color pallet. Adheres to count of needed colors and current dynamics settings.");
-    $self->{'btn'}{'gradient'}->SetToolTip("create gradient between first and current color. Adheres to dynamics settings.");
+    $self->{'btn'}{'gray'}       = Wx::Button->new( $self, -1, 'Gray',       [-1,-1], [45, 17] );
+    $self->{'btn'}{'gradient'}   = Wx::Button->new( $self, -1, 'Gradient',   [-1,-1], [70, 17] );
+    $self->{'btn'}{'complement'} = Wx::Button->new( $self, -1, 'Complement', [-1,-1], [90, 17] );
+    $self->{'btn'}{'gray'}->SetToolTip("reset to default grey scale color pallet. Adheres to count of needed colors and current dynamic settings.");
+    $self->{'btn'}{'gradient'}->SetToolTip("create gradient between first and current color. Adheres to dynamic settings.");
     $self->{'btn'}{'complement'}->SetToolTip("Create color set from first up to current color as complementary colors. Adheres to both delta values.");
-    $self->{'dynamics'}->SetToolTip("dynamics of gradient (1 = linear) and also of gray scale");
-    $self->{'Sdelta'}->SetToolTip("max. satuaration deviation when computing complement colors ( -100 .. 100)");
-    $self->{'Ldelta'}->SetToolTip("max. lightness deviation when computing complement colors ( -100 .. 100)");
+    $self->{'widget'}{'dynamic'}->SetToolTip("dynamic of gradient (1 = linear) and also of gray scale");
+    $self->{'widget'}{'delta_S'}->SetToolTip("max. satuaration deviation when computing complement colors ( -100 .. 100)");
+    $self->{'widget'}{'delta_L'}->SetToolTip("max. lightness deviation when computing complement colors ( -100 .. 100)");
 
 
     $self->{'picker'}  = App::GUI::Cellgraph::Frame::Part::ColorPicker->new( $self, $config->get_value('color') );
@@ -61,23 +63,23 @@ sub new {
 
     Wx::Event::EVT_LEFT_DOWN( $self->{'state_pic'}[$_], sub { $self->select_state( $_[0]->get_nr ) }) for 0 .. $self->{'last_state'};
     Wx::Event::EVT_LEFT_DOWN( $self->{'state_marker'}[$_], sub { $self->select_state( $_[0]->get_nr ) }) for 0 .. $self->{'last_state'};
-    $self->{'state_pic'}[$_]->SetToolTip("select state color $_ to change (marked by arrow - crosses mark currently passive colors)") for 0 .. $self->{'last_state'};
-    $self->{'state_marker'}[$_]->SetToolTip("select state color $_ to change (marked by arrow - crosses mark currently passive colors)") for 0 .. $self->{'last_state'};
+    $self->{'state_pic'}[$_]->SetToolTip("select state color number $_ to change (marked by arrow - crosses mark currently passive colors)") for 0 .. $self->{'last_state'};
+    $self->{'state_marker'}[$_]->SetToolTip("select state color number $_ to change (marked by arrow - crosses mark currently passive colors)") for 0 .. $self->{'last_state'};
 
 
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'gray'}, sub {
-        $self->set_all_colors( color('white')->gradient( to => 'black', steps => $self->{'state_count'}, dynamic => $self->{'dynamics'}->GetValue) );
+        $self->set_all_colors( color('white')->gradient( to => 'black', steps => $self->{'state_count'}, dynamic => $self->{'widget'}{'dynamic'}->GetValue) );
     });
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'gradient'}, sub {
         my @c = $self->get_all_colors;
-        my @new_colors = $c[0]->gradient( to => $c[ $self->{'current_state'} ], in => 'RGB', steps => $self->{'current_state'}+1, dynamics => $self->{'dynamics'}->GetValue);
+        my @new_colors = $c[0]->gradient( to => $c[ $self->{'current_state'} ], in => 'RGB', steps => $self->{'current_state'}+1, dynamic => $self->{'widget'}{'dynamic'}->GetValue);
         $self->set_all_colors( @new_colors );
     });
     Wx::Event::EVT_BUTTON( $self, $self->{'btn'}{'complement'}, sub {
         my @c = $self->get_all_colors;
         my @new_colors = $c[ $self->{'current_state'} ]->complement( steps => $self->{'current_state'}+1,
-                                                                     saturation_tilt => $self->{'Sdelta'}->GetValue,
-                                                                     lightness_tilt => $self->{'Ldelta'}->GetValue );
+                                                                     saturation_tilt => $self->{'widget'}{'delta_S'}->GetValue,
+                                                                     lightness_tilt => $self->{'widget'}{'delta_L'}->GetValue );
         push @new_colors, shift @new_colors;
         $self->set_all_colors( @new_colors );
     });
@@ -86,18 +88,18 @@ sub new {
     my $all_attr = &Wx::wxGROW | &Wx::wxALL | &Wx::wxALIGN_CENTER_HORIZONTAL | &Wx::wxALIGN_CENTER_VERTICAL;
 
     my $f_sizer = Wx::BoxSizer->new(&Wx::wxHORIZONTAL);
-    $f_sizer->AddSpacer( 5 );
+    $f_sizer->AddSpacer( 10 );
     $f_sizer->Add( $self->{'btn'}{'gray'}, 0, $std_attr|&Wx::wxALL, 5 );
     $f_sizer->Add( $self->{'btn'}{'gradient'}, 0, $std_attr|&Wx::wxALL, 5 );
-    $f_sizer->Add( $self->{'dynamics'}, 0, $std_attr|&Wx::wxALL, 5 );
-    $f_sizer->AddSpacer( 25 );
+    $f_sizer->Add( $self->{'widget'}{'dynamic'}, 0, $std_attr|&Wx::wxALL, 5 );
+    $f_sizer->AddSpacer( 20 );
     $f_sizer->Add( $self->{'btn'}{'complement'}, 0, $std_attr|&Wx::wxALL, 5 );
-    $f_sizer->Add( $self->{'Sdelta'}, 0, $std_attr|&Wx::wxALL, 5 );
-    $f_sizer->Add( $self->{'Ldelta'}, 0, $std_attr|&Wx::wxALL, 5 );
+    $f_sizer->Add( $self->{'widget'}{'delta_S'}, 0, $std_attr|&Wx::wxALL, 5 );
+    $f_sizer->Add( $self->{'widget'}{'delta_L'}, 0, $std_attr|&Wx::wxALL, 5 );
     $f_sizer->Add( 0, 1, &Wx::wxEXPAND | &Wx::wxGROW);
 
     my $state_sizer = $self->{'state_sizer'} = Wx::BoxSizer->new(&Wx::wxHORIZONTAL); # $self->{'plate_sizer'}->Clear(1);
-    $state_sizer->AddSpacer( 7 );
+    $state_sizer->AddSpacer( 10 );
     my @option_sizer;
     for my $state (0 .. $self->{'last_state'}){
         $option_sizer[$state] = Wx::BoxSizer->new( &Wx::wxVERTICAL );
@@ -105,7 +107,7 @@ sub new {
         $option_sizer[$state]->Add( $self->{'state_pic'}[$state], 0, $all_attr, 3);
         $option_sizer[$state]->Add( $self->{'state_marker'}[$state], 0, $all_attr, 3);
         $state_sizer->Add( $option_sizer[$state], 0, $all_attr, 5);
-        $state_sizer->AddSpacer( 2 );
+        $state_sizer->AddSpacer( 1 );
     }
     $state_sizer->Add( 0, 1, &Wx::wxEXPAND | &Wx::wxGROW);
 
@@ -145,7 +147,7 @@ sub set_state_count {
     $self->{'state_marker'}[ $self->{'current_state'} ]->set_state('active');
 }
 
-sub SetCallBack {
+sub set_callback {
     my ($self, $code) = @_;
     return unless ref $code eq 'CODE';
     $self->{'call_back'} = $code;
@@ -161,29 +163,30 @@ sub select_state {
     $self->{'browser'}->set_data( $self->{'state_colors'}[$self->{'current_state'}]->rgb_hash, 'silent' );
 }
 
-sub init { $_[0]->set_settings( { 0 => '#FFFFFF', 1 => '#000000', dynamics => 1, delta_S => 0, delta_L => 0 } ) }
+sub init { $_[0]->set_settings( { 0 => '#FFFFFF', 1 => '#000000', dynamic => 1, delta_S => 0, delta_L => 0 } ) }
 
 sub get_settings {
     my ($self) = @_;
     my $data = {
-        objects => $self->{'state_colors'},
-        dynamics => $self->{'dynamics'}->GetValue,
-        delta_S => $self->{'Sdelta'}->GetValue,
-        delta_L => $self->{'Ldelta'}->GetValue,
+        dynamic => $self->{'widget'}{'dynamic'}->GetValue,
+        delta_S => $self->{'widget'}{'delta_S'}->GetValue,
+        delta_L => $self->{'widget'}{'delta_L'}->GetValue,
     };
     $data->{$_} = $self->{'state_colors'}[$_]->values(as => 'string') for 0 .. $self->{'last_state'};
     $data;
 }
+sub get_state {
+    my ($self) = @_;
+    my $data = $self-> get_settings;
+    $data->{'objects'} = $self->{'state_colors'};
+    $data;
+}
 
 sub set_settings {
     my ($self, $data) = @_;
-    return unless ref $data eq 'HASH' and exists $data->{'dynamics'};
-    $self->{'dynamics'}->SetValue( $data->{'dynamics'} );
-    $self->{'Sdelta'}->SetValue( $data->{'delta_S'} );
-    $self->{'Ldelta'}->SetValue( $data->{'delta_L'} );
-    for (0 .. $self->{'last_state'}){
-        $data->{$_} = $default_color_def unless exists $data->{$_};
-    }
+    return unless ref $data eq 'HASH' and exists $data->{'dynamic'};
+    $self->{'widget'}{$_}->SetValue( $data->{$_} )     for qw/dynamic delta_S delta_L/;
+    $data->{$_} = $data->{$_} // $default_color_def    for 0 .. $self->{'last_state'};
     $self->{'state_colors'}[$_] = color( $data->{$_} ) for 0 .. $self->{'last_state'};
     $self->set_all_colors( @{$self->{'state_colors'}} );
     $self->{'objects'} = $self->{'state_colors'};
